@@ -4,7 +4,9 @@ from . import skip_if_no_network
 
 _modulepath = op.dirname(op.abspath(__file__))
 
-central = Interface(config=op.join(op.dirname(op.abspath(__file__)), 'central.cfg'))
+fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
+central = Interface(config=fp)
+
 
 @skip_if_no_network
 def test_global_experiment_listing():
