@@ -2,13 +2,16 @@ from pyxnat import Interface
 import os.path as op
 from . import skip_if_no_network
 
-central = Interface(config=op.join(op.dirname(op.abspath(__file__)), 'central.cfg'))
+fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
+central = Interface(config=fp)
+
 
 @skip_if_no_network
 def test_prearchive_get():
     from pyxnat.core import manage
     pa = manage.PreArchive(central)
-    pc = pa.get()
+    pa.get()
+
 
 @skip_if_no_network
 def test_prearchive_status():
