@@ -29,7 +29,8 @@ _id_set2 = {
     'cid': uuid1().hex,
     'rid': uuid1().hex,
     }
-subj_1 = central.select.project('nosetests3').subject(_id_set1['sid'])
+
+subj_1 = central.select.project('nosetests5').subject(_id_set1['sid'])
 expe_1 = subj_1.experiment(_id_set1['eid'])
 asse_1 = expe_1.assessor(_id_set1['aid'])
 scan_1 = expe_1.scan(_id_set1['cid'])
@@ -78,14 +79,12 @@ def test_05_reconstruction_create():
 
 @skip_if_no_network
 def test_06_multi_create():
-    asse_2 = central.select('/projects/nosetests3/subjects/%(sid)s'
+    asse_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
                             '/experiments/%(eid)s'
-                            '/assessors/%(aid)s' % _id_set2
-                            )
+                            '/assessors/%(aid)s' % _id_set2)
 
-    expe_2 = central.select('/projects/nosetests3/subjects/%(sid)s'
-                            '/experiments/%(eid)s' % _id_set2
-                            )
+    expe_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
+                            '/experiments/%(eid)s' % _id_set2)
 
     assert not asse_2.exists()
     asse_2.create(experiments='xnat:petSessionData',
@@ -95,7 +94,7 @@ def test_06_multi_create():
     assert asse_2.datatype() == 'xnat:petAssessorData'
     assert expe_2.datatype() == 'xnat:petSessionData'
 
-    scan_2 = central.select('/projects/nosetests3/subjects/%(sid)s'
+    scan_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
                             '/experiments/%(eid)s/scans/%(cid)s' % _id_set2
                             ).create()
 
@@ -188,7 +187,7 @@ def test_09_put_dir_file():
     subj_1.resource('test').file('dir/hello.txt').put(local_path)
     assert subj_1.resource('test').file('dir/hello.txt').exists()
     assert int(subj_1.resource('test').file('dir/hello.txt').size()) == \
-                                                os.stat(local_path).st_size
+           os.stat(local_path).st_size
 
 
 @skip_if_no_network
@@ -219,7 +218,7 @@ def test_11_get_copy_file():
     fd = open(fpath, 'rb')
     try:
         assert fd.read() == bytes('Hello XNAT!%s' % os.linesep,
-                                                    encoding='utf8')
+                                  encoding='utf8')
     except TypeError:
         pass
     fd.close()
@@ -242,10 +241,10 @@ def test_12_file_last_modified():
 def test_13_last_modified():
     sid = subj_1.id()
 
-    t1 = central.select('/project/nosetests3').last_modified()[sid]
+    t1 = central.select('/project/nosetests5').last_modified()[sid]
     subj_1.attrs.set('age', '26')
     assert subj_1.attrs.get('age') == '26'
-    t2 = central.select('/project/nosetests3').last_modified()[sid]
+    t2 = central.select('/project/nosetests5').last_modified()[sid]
 
     assert t1 != t2
 
@@ -272,12 +271,12 @@ def test_15_getitem_slice():
 
 
 def test_subject1_parent():
-    project = central.select.project('nosetests3')
+    project = central.select.project('nosetests5')
     assert subj_1.parent()._uri == project._uri
 
 
 def test_project_parent():
-    project = central.select.project('nosetests3')
+    project = central.select.project('nosetests5')
     assert not project.parent()
 
 
@@ -290,7 +289,7 @@ def test_16_subject1_delete():
 
 @skip_if_no_network
 def test_17_subject2_delete():
-    subj_2 = central.select('/projects/nosetests3/subjects/%(sid)s'%_id_set2)
+    subj_2 = central.select('/projects/nosetests5/subjects/%(sid)s' % _id_set2)
     assert subj_2.exists()
     subj_2.delete()
     assert not subj_2.exists()
@@ -298,7 +297,7 @@ def test_17_subject2_delete():
 
 @skip_if_no_network
 def test_18_project_configuration():
-    project = central.select('/project/nosetests3')
+    project = central.select('/project/nosetests5')
     version = central.version()
     from pyxnat.core.errors import DatabaseError
 
@@ -316,10 +315,9 @@ def test_18_project_configuration():
             assert project.current_arc() == b'arc001'
         except DatabaseError:
             msg = 'Check if current_arc is supported in XNAT version %s.'\
-                %version['version']
+                 % version['version']
             print(msg)
 
-
     assert 'nosetests' in project.users()
     assert 'nosetests' in project.owners()
     assert project.user_role('nosetests') == 'owner'
@@ -366,13 +364,20 @@ def test_20_get_zip():
 
 @skip_if_no_network
 def test_21_project_aliases():
-    project = central.select('/project/nosetests3')
-    assert project.aliases() ==  ['nosetests32']
+    project = central.select('/project/nosetests5')
+    assert project.aliases() == ['nosetests52']
 
 
 @skip_if_no_network
 def test_22_project():
-    project = central.select.project('nosetests3')
+    project = central.select.project('nosetests5')
     project.datatype()
     project.experiments()
     project.experiment('nose')
+
+
+@skip_if_no_network
+def test_22_project_description():
+    project = central.select.project('nosetests5')
+    desc = project.description()
+    assert(desc == 'nosetests')
