@@ -1,11 +1,13 @@
 from pyxnat import Interface
 import os.path as op
 from . import skip_if_no_network
-from nose import SkipTest
+
 
 _modulepath = op.dirname(op.abspath(__file__))
 
-central = Interface(config=op.join(op.dirname(op.abspath(__file__)), 'central.cfg'))
+fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
+central = Interface(config=fp)
+
 
 @skip_if_no_network
 def test_global_scan_listing():
